==> webkit2gtk_2.5.3%2Bdfsg1.orig.tar.xz: webkit2gtk-2.5.3+dfsg1/Source/WebCore/platform/RuntimeApplicationChecksIOS.h <==
/*
 * Copyright (C) 2009 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer. 
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution. 
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE AND ITS CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE OR ITS CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef RuntimeApplicationChecksIOS_h
#define RuntimeApplicationChecksIOS_h

// FIXME: We should consider merging this file with RuntimeApplicationChecks.h.
namespace WebCore {

bool applicationIsAdSheet();
bool applicationIsMobileMail();
bool applicationIsMobileSafari();
bool applicationIsDumpRenderTree();
bool applicationIsMobileStore();
bool applicationIsWebApp();
bool applicationIsOkCupid();
bool applicationIsFacebook();
bool applicationIsEpicurious();
bool applicationIsDaijisenDictionary();
bool applicationIsNASAHD();
bool applicationIsMASH();
bool applicationIsTheEconomistOnIPhone();
bool applicationIsWebProcess();
bool applicationIsIBooksOnIOS();

} // namespace WebCore

#endif // RuntimeApplicationChecksIOS_h

==> webkit2gtk_2.9.3%2Bdfsg1.orig.tar.xz: webkit2gtk-2.9.3+dfsg1/Source/WebCore/platform/RuntimeApplicationChecksIOS.h <==
/*
 * Copyright (C) 2009 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer. 
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution. 
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE AND ITS CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE OR ITS CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef RuntimeApplicationChecksIOS_h
#define RuntimeApplicationChecksIOS_h

// FIXME: We should consider merging this file with RuntimeApplicationChecks.h.
namespace WebCore {

WEBCORE_EXPORT bool applicationIsMobileMail();
WEBCORE_EXPORT bool applicationIsMobileSafari();
bool applicationIsDumpRenderTree();
bool applicationIsMobileStore();
WEBCORE_EXPORT bool applicationIsWebApp();
WEBCORE_EXPORT bool applicationIsOkCupid();
WEBCORE_EXPORT bool applicationIsFacebook();
bool applicationIsEpicurious();
WEBCORE_EXPORT bool applicationIsDaijisenDictionary();
bool applicationIsNASAHD();
bool applicationIsMASH();
WEBCORE_EXPORT bool applicationIsTheEconomistOnIPhone();
bool applicationIsWebProcess();
bool applicationIsIBooksOnIOS();

} // namespace WebCore

#endif // RuntimeApplicationChecksIOS_h
